// python wrapper for vtkGlobeSource
//
#define VTK_WRAPPING_CXX
#define VTK_STREAMS_FWD_ONLY
#include "vtkPythonArgs.h"
#include "vtkPythonOverload.h"
#include "vtkConfigure.h"
#include <cstddef>
#include <sstream>
#include "vtkVariant.h"
#include "vtkIndent.h"
#include "vtkGlobeSource.h"

extern "C" { VTK_ABI_EXPORT void PyVTKAddFile_vtkGlobeSource(PyObject *); }
extern "C" { VTK_ABI_EXPORT PyObject *PyvtkGlobeSource_ClassNew(); }

#ifndef DECLARED_PyvtkPolyDataAlgorithm_ClassNew
extern "C" { PyObject *PyvtkPolyDataAlgorithm_ClassNew(); }
#define DECLARED_PyvtkPolyDataAlgorithm_ClassNew
#endif

static const char *PyvtkGlobeSource_Doc =
  "vtkGlobeSource - Sphere patch with Lat/Long scalar array.\n\n"
  "Superclass: vtkPolyDataAlgorithm\n\n"
  "vtkGlobeSource will generate any \"rectangular\" patch of the globe\n"
  "given its Longitude-Latitude extent.  It adds two point scalar arrays\n"
  "Longitude and Latitude to the output.  These arrays can be\n"
  "transformed to generate texture coordinates for any texture map. \n"
  "This source is imperfect near the poles as implemented.  It should\n"
  "really reduce the longitude resolution as the triangles become\n"
  "slivers.\n\n"
  "\\image html vtkGlobeSourceSphericalToCartesianFigure.png\\image latex\n"
  "vtkGlobeSourceSphericalToCartesianFigure.eps\n\n";


static PyObject *
PyvtkGlobeSource_IsTypeOf(PyObject *, PyObject *args)
{
  vtkPythonArgs ap(args, "IsTypeOf");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkGlobeSource::IsTypeOf(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_IsA(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsA");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->IsA(temp0) :
      op->vtkGlobeSource::IsA(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_SafeDownCast(PyObject *, PyObject *args)
{
  vtkPythonArgs ap(args, "SafeDownCast");

  vtkObjectBase *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkObjectBase"))
  {
    vtkGlobeSource *tempr = vtkGlobeSource::SafeDownCast(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_NewInstance(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "NewInstance");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkGlobeSource *tempr = (ap.IsBound() ?
      op->NewInstance() :
      op->vtkGlobeSource::NewInstance());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
      if (result && PyVTKObject_Check(result))
      {
        PyVTKObject_GetObject(result)->UnRegister(0);
        PyVTKObject_SetFlag(result, VTK_PYTHON_IGNORE_UNREGISTER, 1);
      }
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_SetOrigin_s1(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetOrigin");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  double temp0;
  double temp1;
  double temp2;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(3) &&
      ap.GetValue(temp0) &&
      ap.GetValue(temp1) &&
      ap.GetValue(temp2))
  {
    if (ap.IsBound())
    {
      op->SetOrigin(temp0, temp1, temp2);
    }
    else
    {
      op->vtkGlobeSource::SetOrigin(temp0, temp1, temp2);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}

static PyObject *
PyvtkGlobeSource_SetOrigin_s2(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetOrigin");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  const size_t size0 = 3;
  double temp0[3];
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetArray(temp0, size0))
  {
    if (ap.IsBound())
    {
      op->SetOrigin(temp0);
    }
    else
    {
      op->vtkGlobeSource::SetOrigin(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}

static PyObject *
PyvtkGlobeSource_SetOrigin(PyObject *self, PyObject *args)
{
  int nargs = vtkPythonArgs::GetArgCount(self, args);

  switch(nargs)
  {
    case 3:
      return PyvtkGlobeSource_SetOrigin_s1(self, args);
    case 1:
      return PyvtkGlobeSource_SetOrigin_s2(self, args);
  }

  vtkPythonArgs::ArgCountError(nargs, "SetOrigin");
  return nullptr;
}



static PyObject *
PyvtkGlobeSource_SetStartLongitude(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetStartLongitude");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  double temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetStartLongitude(temp0);
    }
    else
    {
      op->vtkGlobeSource::SetStartLongitude(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_GetStartLongitudeMinValue(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetStartLongitudeMinValue");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    double tempr = (ap.IsBound() ?
      op->GetStartLongitudeMinValue() :
      op->vtkGlobeSource::GetStartLongitudeMinValue());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_GetStartLongitudeMaxValue(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetStartLongitudeMaxValue");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    double tempr = (ap.IsBound() ?
      op->GetStartLongitudeMaxValue() :
      op->vtkGlobeSource::GetStartLongitudeMaxValue());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_SetEndLongitude(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetEndLongitude");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  double temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetEndLongitude(temp0);
    }
    else
    {
      op->vtkGlobeSource::SetEndLongitude(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_GetEndLongitudeMinValue(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetEndLongitudeMinValue");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    double tempr = (ap.IsBound() ?
      op->GetEndLongitudeMinValue() :
      op->vtkGlobeSource::GetEndLongitudeMinValue());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_GetEndLongitudeMaxValue(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetEndLongitudeMaxValue");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    double tempr = (ap.IsBound() ?
      op->GetEndLongitudeMaxValue() :
      op->vtkGlobeSource::GetEndLongitudeMaxValue());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_SetStartLatitude(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetStartLatitude");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  double temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetStartLatitude(temp0);
    }
    else
    {
      op->vtkGlobeSource::SetStartLatitude(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_GetStartLatitudeMinValue(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetStartLatitudeMinValue");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    double tempr = (ap.IsBound() ?
      op->GetStartLatitudeMinValue() :
      op->vtkGlobeSource::GetStartLatitudeMinValue());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_GetStartLatitudeMaxValue(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetStartLatitudeMaxValue");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    double tempr = (ap.IsBound() ?
      op->GetStartLatitudeMaxValue() :
      op->vtkGlobeSource::GetStartLatitudeMaxValue());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_SetEndLatitude(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetEndLatitude");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  double temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetEndLatitude(temp0);
    }
    else
    {
      op->vtkGlobeSource::SetEndLatitude(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_GetEndLatitudeMinValue(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetEndLatitudeMinValue");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    double tempr = (ap.IsBound() ?
      op->GetEndLatitudeMinValue() :
      op->vtkGlobeSource::GetEndLatitudeMinValue());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_GetEndLatitudeMaxValue(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetEndLatitudeMaxValue");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    double tempr = (ap.IsBound() ?
      op->GetEndLatitudeMaxValue() :
      op->vtkGlobeSource::GetEndLatitudeMaxValue());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_SetLongitudeResolution(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetLongitudeResolution");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetLongitudeResolution(temp0);
    }
    else
    {
      op->vtkGlobeSource::SetLongitudeResolution(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_GetLongitudeResolutionMinValue(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetLongitudeResolutionMinValue");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetLongitudeResolutionMinValue() :
      op->vtkGlobeSource::GetLongitudeResolutionMinValue());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_GetLongitudeResolutionMaxValue(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetLongitudeResolutionMaxValue");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetLongitudeResolutionMaxValue() :
      op->vtkGlobeSource::GetLongitudeResolutionMaxValue());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_GetLongitudeResolution(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetLongitudeResolution");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetLongitudeResolution() :
      op->vtkGlobeSource::GetLongitudeResolution());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_SetLatitudeResolution(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetLatitudeResolution");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetLatitudeResolution(temp0);
    }
    else
    {
      op->vtkGlobeSource::SetLatitudeResolution(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_GetLatitudeResolutionMinValue(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetLatitudeResolutionMinValue");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetLatitudeResolutionMinValue() :
      op->vtkGlobeSource::GetLatitudeResolutionMinValue());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_GetLatitudeResolutionMaxValue(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetLatitudeResolutionMaxValue");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetLatitudeResolutionMaxValue() :
      op->vtkGlobeSource::GetLatitudeResolutionMaxValue());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_GetLatitudeResolution(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetLatitudeResolution");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetLatitudeResolution() :
      op->vtkGlobeSource::GetLatitudeResolution());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_SetRadius(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetRadius");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  double temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetRadius(temp0);
    }
    else
    {
      op->vtkGlobeSource::SetRadius(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_GetRadiusMinValue(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetRadiusMinValue");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    double tempr = (ap.IsBound() ?
      op->GetRadiusMinValue() :
      op->vtkGlobeSource::GetRadiusMinValue());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_GetRadiusMaxValue(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetRadiusMaxValue");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    double tempr = (ap.IsBound() ?
      op->GetRadiusMaxValue() :
      op->vtkGlobeSource::GetRadiusMaxValue());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_GetRadius(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetRadius");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    double tempr = (ap.IsBound() ?
      op->GetRadius() :
      op->vtkGlobeSource::GetRadius());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_SetAutoCalculateCurtainHeight(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetAutoCalculateCurtainHeight");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  bool temp0 = false;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetAutoCalculateCurtainHeight(temp0);
    }
    else
    {
      op->vtkGlobeSource::SetAutoCalculateCurtainHeight(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_GetAutoCalculateCurtainHeight(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetAutoCalculateCurtainHeight");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    bool tempr = (ap.IsBound() ?
      op->GetAutoCalculateCurtainHeight() :
      op->vtkGlobeSource::GetAutoCalculateCurtainHeight());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_AutoCalculateCurtainHeightOn(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "AutoCalculateCurtainHeightOn");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->AutoCalculateCurtainHeightOn();
    }
    else
    {
      op->vtkGlobeSource::AutoCalculateCurtainHeightOn();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_AutoCalculateCurtainHeightOff(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "AutoCalculateCurtainHeightOff");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->AutoCalculateCurtainHeightOff();
    }
    else
    {
      op->vtkGlobeSource::AutoCalculateCurtainHeightOff();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_SetCurtainHeight(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetCurtainHeight");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  double temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetCurtainHeight(temp0);
    }
    else
    {
      op->vtkGlobeSource::SetCurtainHeight(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_GetCurtainHeightMinValue(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetCurtainHeightMinValue");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    double tempr = (ap.IsBound() ?
      op->GetCurtainHeightMinValue() :
      op->vtkGlobeSource::GetCurtainHeightMinValue());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_GetCurtainHeightMaxValue(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetCurtainHeightMaxValue");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    double tempr = (ap.IsBound() ?
      op->GetCurtainHeightMaxValue() :
      op->vtkGlobeSource::GetCurtainHeightMaxValue());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_GetCurtainHeight(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetCurtainHeight");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    double tempr = (ap.IsBound() ?
      op->GetCurtainHeight() :
      op->vtkGlobeSource::GetCurtainHeight());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_SetQuadrilateralTessellation(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetQuadrilateralTessellation");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetQuadrilateralTessellation(temp0);
    }
    else
    {
      op->vtkGlobeSource::SetQuadrilateralTessellation(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_GetQuadrilateralTessellation(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetQuadrilateralTessellation");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetQuadrilateralTessellation() :
      op->vtkGlobeSource::GetQuadrilateralTessellation());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_QuadrilateralTessellationOn(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "QuadrilateralTessellationOn");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->QuadrilateralTessellationOn();
    }
    else
    {
      op->vtkGlobeSource::QuadrilateralTessellationOn();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_QuadrilateralTessellationOff(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "QuadrilateralTessellationOff");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGlobeSource *op = static_cast<vtkGlobeSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->QuadrilateralTessellationOff();
    }
    else
    {
      op->vtkGlobeSource::QuadrilateralTessellationOff();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_ComputeGlobePoint(PyObject *, PyObject *args)
{
  vtkPythonArgs ap(args, "ComputeGlobePoint");

  double temp0;
  double temp1;
  double temp2;
  size_t size3 = ap.GetArgSize(3);
  vtkPythonArgs::Array<double> store3(2*size3);
  double *temp3 = store3.Data();
  double *save3 = (size3 == 0 ? nullptr : temp3 + size3);
  size_t size4 = ap.GetArgSize(4);
  vtkPythonArgs::Array<double> store4(2*size4);
  double *temp4 = store4.Data();
  double *save4 = (size4 == 0 ? nullptr : temp4 + size4);
  PyObject *result = nullptr;

  if (ap.CheckArgCount(4, 5) &&
      ap.GetValue(temp0) &&
      ap.GetValue(temp1) &&
      ap.GetValue(temp2) &&
      ap.GetArray(temp3, size3) &&
      (ap.NoArgsLeft() || ap.GetArray(temp4, size4)))
  {
    ap.Save(temp3, save3, size3);
    ap.Save(temp4, save4, size4);

    vtkGlobeSource::ComputeGlobePoint(temp0, temp1, temp2, temp3, temp4);

    if (ap.HasChanged(temp3, save3, size3) &&
        !ap.ErrorOccurred())
    {
      ap.SetArray(3, temp3, size3);
    }

    if (ap.HasChanged(temp4, save4, size4) &&
        !ap.ErrorOccurred())
    {
      ap.SetArray(4, temp4, size4);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkGlobeSource_ComputeLatitudeLongitude(PyObject *, PyObject *args)
{
  vtkPythonArgs ap(args, "ComputeLatitudeLongitude");

  size_t size0 = ap.GetArgSize(0);
  vtkPythonArgs::Array<double> store0(2*size0);
  double *temp0 = store0.Data();
  double *save0 = (size0 == 0 ? nullptr : temp0 + size0);
  double temp1;
  double temp2;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(3) &&
      ap.GetArray(temp0, size0) &&
      ap.GetValue(temp1) &&
      ap.GetValue(temp2))
  {
    ap.Save(temp0, save0, size0);

    vtkGlobeSource::ComputeLatitudeLongitude(temp0, temp1, temp2);

    if (ap.HasChanged(temp0, save0, size0) &&
        !ap.ErrorOccurred())
    {
      ap.SetArray(0, temp0, size0);
    }

    if (!ap.ErrorOccurred())
    {
      ap.SetArgValue(1, temp1);
    }
    if (!ap.ErrorOccurred())
    {
      ap.SetArgValue(2, temp2);
    }
    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}

static PyMethodDef PyvtkGlobeSource_Methods[] = {
  {"IsTypeOf", PyvtkGlobeSource_IsTypeOf, METH_VARARGS,
   "V.IsTypeOf(string) -> int\nC++: static vtkTypeBool IsTypeOf(const char *type)\n\nReturn 1 if this class type is the same type of (or a subclass\nof) the named class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"IsA", PyvtkGlobeSource_IsA, METH_VARARGS,
   "V.IsA(string) -> int\nC++: vtkTypeBool IsA(const char *type) override;\n\nReturn 1 if this class is the same type of (or a subclass of) the\nnamed class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SafeDownCast", PyvtkGlobeSource_SafeDownCast, METH_VARARGS,
   "V.SafeDownCast(vtkObjectBase) -> vtkGlobeSource\nC++: static vtkGlobeSource *SafeDownCast(vtkObjectBase *o)\n\n"},
  {"NewInstance", PyvtkGlobeSource_NewInstance, METH_VARARGS,
   "V.NewInstance() -> vtkGlobeSource\nC++: vtkGlobeSource *NewInstance()\n\n"},
  {"SetOrigin", PyvtkGlobeSource_SetOrigin, METH_VARARGS,
   "V.SetOrigin(float, float, float)\nC++: void SetOrigin(double, double, double)\nV.SetOrigin((float, float, float))\nC++: void SetOrigin(double a[3])\n\n"},
  {"SetStartLongitude", PyvtkGlobeSource_SetStartLongitude, METH_VARARGS,
   "V.SetStartLongitude(float)\nC++: virtual void SetStartLongitude(double _arg)\n\nLongitude Latitude clamps.\n"},
  {"GetStartLongitudeMinValue", PyvtkGlobeSource_GetStartLongitudeMinValue, METH_VARARGS,
   "V.GetStartLongitudeMinValue() -> float\nC++: virtual double GetStartLongitudeMinValue()\n\nLongitude Latitude clamps.\n"},
  {"GetStartLongitudeMaxValue", PyvtkGlobeSource_GetStartLongitudeMaxValue, METH_VARARGS,
   "V.GetStartLongitudeMaxValue() -> float\nC++: virtual double GetStartLongitudeMaxValue()\n\nLongitude Latitude clamps.\n"},
  {"SetEndLongitude", PyvtkGlobeSource_SetEndLongitude, METH_VARARGS,
   "V.SetEndLongitude(float)\nC++: virtual void SetEndLongitude(double _arg)\n\nLongitude Latitude clamps.\n"},
  {"GetEndLongitudeMinValue", PyvtkGlobeSource_GetEndLongitudeMinValue, METH_VARARGS,
   "V.GetEndLongitudeMinValue() -> float\nC++: virtual double GetEndLongitudeMinValue()\n\nLongitude Latitude clamps.\n"},
  {"GetEndLongitudeMaxValue", PyvtkGlobeSource_GetEndLongitudeMaxValue, METH_VARARGS,
   "V.GetEndLongitudeMaxValue() -> float\nC++: virtual double GetEndLongitudeMaxValue()\n\nLongitude Latitude clamps.\n"},
  {"SetStartLatitude", PyvtkGlobeSource_SetStartLatitude, METH_VARARGS,
   "V.SetStartLatitude(float)\nC++: virtual void SetStartLatitude(double _arg)\n\nLongitude Latitude clamps.\n"},
  {"GetStartLatitudeMinValue", PyvtkGlobeSource_GetStartLatitudeMinValue, METH_VARARGS,
   "V.GetStartLatitudeMinValue() -> float\nC++: virtual double GetStartLatitudeMinValue()\n\nLongitude Latitude clamps.\n"},
  {"GetStartLatitudeMaxValue", PyvtkGlobeSource_GetStartLatitudeMaxValue, METH_VARARGS,
   "V.GetStartLatitudeMaxValue() -> float\nC++: virtual double GetStartLatitudeMaxValue()\n\nLongitude Latitude clamps.\n"},
  {"SetEndLatitude", PyvtkGlobeSource_SetEndLatitude, METH_VARARGS,
   "V.SetEndLatitude(float)\nC++: virtual void SetEndLatitude(double _arg)\n\nLongitude Latitude clamps.\n"},
  {"GetEndLatitudeMinValue", PyvtkGlobeSource_GetEndLatitudeMinValue, METH_VARARGS,
   "V.GetEndLatitudeMinValue() -> float\nC++: virtual double GetEndLatitudeMinValue()\n\nLongitude Latitude clamps.\n"},
  {"GetEndLatitudeMaxValue", PyvtkGlobeSource_GetEndLatitudeMaxValue, METH_VARARGS,
   "V.GetEndLatitudeMaxValue() -> float\nC++: virtual double GetEndLatitudeMaxValue()\n\nLongitude Latitude clamps.\n"},
  {"SetLongitudeResolution", PyvtkGlobeSource_SetLongitudeResolution, METH_VARARGS,
   "V.SetLongitudeResolution(int)\nC++: virtual void SetLongitudeResolution(int _arg)\n\nSet the number of points in the longitude direction (ranging from\nStartLongitude to EndLongitude).\n"},
  {"GetLongitudeResolutionMinValue", PyvtkGlobeSource_GetLongitudeResolutionMinValue, METH_VARARGS,
   "V.GetLongitudeResolutionMinValue() -> int\nC++: virtual int GetLongitudeResolutionMinValue()\n\nSet the number of points in the longitude direction (ranging from\nStartLongitude to EndLongitude).\n"},
  {"GetLongitudeResolutionMaxValue", PyvtkGlobeSource_GetLongitudeResolutionMaxValue, METH_VARARGS,
   "V.GetLongitudeResolutionMaxValue() -> int\nC++: virtual int GetLongitudeResolutionMaxValue()\n\nSet the number of points in the longitude direction (ranging from\nStartLongitude to EndLongitude).\n"},
  {"GetLongitudeResolution", PyvtkGlobeSource_GetLongitudeResolution, METH_VARARGS,
   "V.GetLongitudeResolution() -> int\nC++: virtual int GetLongitudeResolution()\n\nSet the number of points in the longitude direction (ranging from\nStartLongitude to EndLongitude).\n"},
  {"SetLatitudeResolution", PyvtkGlobeSource_SetLatitudeResolution, METH_VARARGS,
   "V.SetLatitudeResolution(int)\nC++: virtual void SetLatitudeResolution(int _arg)\n\nSet the number of points in the latitude direction (ranging from\nStartLatitude to EndLatitude).\n"},
  {"GetLatitudeResolutionMinValue", PyvtkGlobeSource_GetLatitudeResolutionMinValue, METH_VARARGS,
   "V.GetLatitudeResolutionMinValue() -> int\nC++: virtual int GetLatitudeResolutionMinValue()\n\nSet the number of points in the latitude direction (ranging from\nStartLatitude to EndLatitude).\n"},
  {"GetLatitudeResolutionMaxValue", PyvtkGlobeSource_GetLatitudeResolutionMaxValue, METH_VARARGS,
   "V.GetLatitudeResolutionMaxValue() -> int\nC++: virtual int GetLatitudeResolutionMaxValue()\n\nSet the number of points in the latitude direction (ranging from\nStartLatitude to EndLatitude).\n"},
  {"GetLatitudeResolution", PyvtkGlobeSource_GetLatitudeResolution, METH_VARARGS,
   "V.GetLatitudeResolution() -> int\nC++: virtual int GetLatitudeResolution()\n\nSet the number of points in the latitude direction (ranging from\nStartLatitude to EndLatitude).\n"},
  {"SetRadius", PyvtkGlobeSource_SetRadius, METH_VARARGS,
   "V.SetRadius(float)\nC++: virtual void SetRadius(double _arg)\n\nSet radius of sphere. Default is 6356750.0\n"},
  {"GetRadiusMinValue", PyvtkGlobeSource_GetRadiusMinValue, METH_VARARGS,
   "V.GetRadiusMinValue() -> float\nC++: virtual double GetRadiusMinValue()\n\nSet radius of sphere. Default is 6356750.0\n"},
  {"GetRadiusMaxValue", PyvtkGlobeSource_GetRadiusMaxValue, METH_VARARGS,
   "V.GetRadiusMaxValue() -> float\nC++: virtual double GetRadiusMaxValue()\n\nSet radius of sphere. Default is 6356750.0\n"},
  {"GetRadius", PyvtkGlobeSource_GetRadius, METH_VARARGS,
   "V.GetRadius() -> float\nC++: virtual double GetRadius()\n\nSet radius of sphere. Default is 6356750.0\n"},
  {"SetAutoCalculateCurtainHeight", PyvtkGlobeSource_SetAutoCalculateCurtainHeight, METH_VARARGS,
   "V.SetAutoCalculateCurtainHeight(bool)\nC++: virtual void SetAutoCalculateCurtainHeight(bool _arg)\n\n"},
  {"GetAutoCalculateCurtainHeight", PyvtkGlobeSource_GetAutoCalculateCurtainHeight, METH_VARARGS,
   "V.GetAutoCalculateCurtainHeight() -> bool\nC++: virtual bool GetAutoCalculateCurtainHeight()\n\n"},
  {"AutoCalculateCurtainHeightOn", PyvtkGlobeSource_AutoCalculateCurtainHeightOn, METH_VARARGS,
   "V.AutoCalculateCurtainHeightOn()\nC++: virtual void AutoCalculateCurtainHeightOn()\n\n"},
  {"AutoCalculateCurtainHeightOff", PyvtkGlobeSource_AutoCalculateCurtainHeightOff, METH_VARARGS,
   "V.AutoCalculateCurtainHeightOff()\nC++: virtual void AutoCalculateCurtainHeightOff()\n\n"},
  {"SetCurtainHeight", PyvtkGlobeSource_SetCurtainHeight, METH_VARARGS,
   "V.SetCurtainHeight(float)\nC++: virtual void SetCurtainHeight(double _arg)\n\nSet/Get curtain height.\n"},
  {"GetCurtainHeightMinValue", PyvtkGlobeSource_GetCurtainHeightMinValue, METH_VARARGS,
   "V.GetCurtainHeightMinValue() -> float\nC++: virtual double GetCurtainHeightMinValue()\n\nSet/Get curtain height.\n"},
  {"GetCurtainHeightMaxValue", PyvtkGlobeSource_GetCurtainHeightMaxValue, METH_VARARGS,
   "V.GetCurtainHeightMaxValue() -> float\nC++: virtual double GetCurtainHeightMaxValue()\n\nSet/Get curtain height.\n"},
  {"GetCurtainHeight", PyvtkGlobeSource_GetCurtainHeight, METH_VARARGS,
   "V.GetCurtainHeight() -> float\nC++: virtual double GetCurtainHeight()\n\nSet/Get curtain height.\n"},
  {"SetQuadrilateralTessellation", PyvtkGlobeSource_SetQuadrilateralTessellation, METH_VARARGS,
   "V.SetQuadrilateralTessellation(int)\nC++: virtual void SetQuadrilateralTessellation(vtkTypeBool _arg)\n\nCause the sphere to be tessellated with edges along the latitude\nand longitude lines. If off, triangles are generated at non-polar\nregions, which results in edges that are not parallel to latitude\nand longitude lines. If on, quadrilaterals are generated\neverywhere except at the poles. This can be useful for generating\na wireframe sphere with natural latitude and longitude lines.\n"},
  {"GetQuadrilateralTessellation", PyvtkGlobeSource_GetQuadrilateralTessellation, METH_VARARGS,
   "V.GetQuadrilateralTessellation() -> int\nC++: virtual vtkTypeBool GetQuadrilateralTessellation()\n\nCause the sphere to be tessellated with edges along the latitude\nand longitude lines. If off, triangles are generated at non-polar\nregions, which results in edges that are not parallel to latitude\nand longitude lines. If on, quadrilaterals are generated\neverywhere except at the poles. This can be useful for generating\na wireframe sphere with natural latitude and longitude lines.\n"},
  {"QuadrilateralTessellationOn", PyvtkGlobeSource_QuadrilateralTessellationOn, METH_VARARGS,
   "V.QuadrilateralTessellationOn()\nC++: virtual void QuadrilateralTessellationOn()\n\nCause the sphere to be tessellated with edges along the latitude\nand longitude lines. If off, triangles are generated at non-polar\nregions, which results in edges that are not parallel to latitude\nand longitude lines. If on, quadrilaterals are generated\neverywhere except at the poles. This can be useful for generating\na wireframe sphere with natural latitude and longitude lines.\n"},
  {"QuadrilateralTessellationOff", PyvtkGlobeSource_QuadrilateralTessellationOff, METH_VARARGS,
   "V.QuadrilateralTessellationOff()\nC++: virtual void QuadrilateralTessellationOff()\n\nCause the sphere to be tessellated with edges along the latitude\nand longitude lines. If off, triangles are generated at non-polar\nregions, which results in edges that are not parallel to latitude\nand longitude lines. If on, quadrilaterals are generated\neverywhere except at the poles. This can be useful for generating\na wireframe sphere with natural latitude and longitude lines.\n"},
  {"ComputeGlobePoint", PyvtkGlobeSource_ComputeGlobePoint, METH_VARARGS,
   "V.ComputeGlobePoint(float, float, float, [float, ...], [float,\n    ...])\nC++: static void ComputeGlobePoint(double theta, double phi,\n    double radius, double *point, double *normal=nullptr)\n\nCalculates the normal and point on a sphere with a specified\nradius at the spherical coordinates theta and phi.\n"},
  {"ComputeLatitudeLongitude", PyvtkGlobeSource_ComputeLatitudeLongitude, METH_VARARGS,
   "V.ComputeLatitudeLongitude([float, ...], float, float)\nC++: static void ComputeLatitudeLongitude(double *x,\n    double &theta, double &phi)\n\nCalculates the spherical coordinates theta and phi based on the\npoint on a sphere.\n"},
  {nullptr, nullptr, 0, nullptr}
};

static PyTypeObject PyvtkGlobeSource_Type = {
  PyVarObject_HEAD_INIT(&PyType_Type, 0)
  "vtkGeovisCorePython.vtkGlobeSource", // tp_name
  sizeof(PyVTKObject), // tp_basicsize
  0, // tp_itemsize
  PyVTKObject_Delete, // tp_dealloc
  0, // tp_vectorcall_offset
  nullptr, // tp_getattr
  nullptr, // tp_setattr
  nullptr, // tp_compare
  PyVTKObject_Repr, // tp_repr
  nullptr, // tp_as_number
  nullptr, // tp_as_sequence
  nullptr, // tp_as_mapping
  nullptr, // tp_hash
  nullptr, // tp_call
  PyVTKObject_String, // tp_str
  PyObject_GenericGetAttr, // tp_getattro
  PyObject_GenericSetAttr, // tp_setattro
  &PyVTKObject_AsBuffer, // tp_as_buffer
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_BASETYPE, // tp_flags
  PyvtkGlobeSource_Doc, // tp_doc
  PyVTKObject_Traverse, // tp_traverse
  nullptr, // tp_clear
  nullptr, // tp_richcompare
  offsetof(PyVTKObject, vtk_weakreflist), // tp_weaklistoffset
  nullptr, // tp_iter
  nullptr, // tp_iternext
  nullptr, // tp_methods
  nullptr, // tp_members
  PyVTKObject_GetSet, // tp_getset
  nullptr, // tp_base
  nullptr, // tp_dict
  nullptr, // tp_descr_get
  nullptr, // tp_descr_set
  offsetof(PyVTKObject, vtk_dict), // tp_dictoffset
  nullptr, // tp_init
  nullptr, // tp_alloc
  PyVTKObject_New, // tp_new
  PyObject_GC_Del, // tp_free
  nullptr, // tp_is_gc
  nullptr, // tp_bases
  nullptr, // tp_mro
  nullptr, // tp_cache
  nullptr, // tp_subclasses
  nullptr, // tp_weaklist
  VTK_WRAP_PYTHON_SUPPRESS_UNINITIALIZED
};

static vtkObjectBase *PyvtkGlobeSource_StaticNew()
{
  return vtkGlobeSource::New();
}

PyObject *PyvtkGlobeSource_ClassNew()
{
  PyVTKClass_Add(
    &PyvtkGlobeSource_Type, PyvtkGlobeSource_Methods,
    "vtkGlobeSource",
 &PyvtkGlobeSource_StaticNew);

  PyTypeObject *pytype = &PyvtkGlobeSource_Type;

  if ((pytype->tp_flags & Py_TPFLAGS_READY) != 0)
  {
    return (PyObject *)pytype;
  }

#if !defined(VTK_PY3K) && PY_VERSION_HEX >= 0x02060000
  pytype->tp_flags |= Py_TPFLAGS_HAVE_NEWBUFFER;
#endif

  pytype->tp_base = (PyTypeObject *)PyvtkPolyDataAlgorithm_ClassNew();

  PyType_Ready(pytype);
  return (PyObject *)pytype;
}

void PyVTKAddFile_vtkGlobeSource(
  PyObject *dict)
{
  PyObject *o;
  o = PyvtkGlobeSource_ClassNew();

  if (o && PyDict_SetItemString(dict, "vtkGlobeSource", o) != 0)
  {
    Py_DECREF(o);
  }

}

