// python wrapper for vtkPostgreSQLDatabase
//
#define VTK_WRAPPING_CXX
#define VTK_STREAMS_FWD_ONLY
#include "vtkPythonArgs.h"
#include "vtkPythonOverload.h"
#include "vtkConfigure.h"
#include <cstddef>
#include <sstream>
#include "vtkVariant.h"
#include "vtkIndent.h"
#include "vtkStdString.h"
#include "vtkPostgreSQLDatabase.h"

extern "C" { VTK_ABI_EXPORT void PyVTKAddFile_vtkPostgreSQLDatabase(PyObject *); }
extern "C" { VTK_ABI_EXPORT PyObject *PyvtkPostgreSQLDatabase_ClassNew(); }

#ifndef DECLARED_PyvtkSQLDatabase_ClassNew
extern "C" { PyObject *PyvtkSQLDatabase_ClassNew(); }
#define DECLARED_PyvtkSQLDatabase_ClassNew
#endif

static const char *PyvtkPostgreSQLDatabase_Doc =
  "vtkPostgreSQLDatabase - maintain a connection to a PostgreSQL database\n\n"
  "Superclass: vtkSQLDatabase\n\n"
  "PostgreSQL (http://www.postgres.org) is a BSD-licensed SQL database.\n"
  "It's large, fast, and can not be easily embedded inside other\n"
  "applications.  Its databases are stored in files that belong to\n"
  "another process.\n\n"
  "This class provides a VTK interface to PostgreSQL.  You do need to\n"
  "download external libraries: we need a copy of PostgreSQL 8\n"
  "(currently 8.2 or 8.3) so that we can link against the libpq C\n"
  "interface.\n\n"
  "@par Thanks: Thanks to David Thompson and Andy Wilson from Sandia\n"
  "National Laboratories for implementing this class.\n\n"
  "@sa\n"
  "vtkPostgreSQLQuery\n\n";


static PyObject *
PyvtkPostgreSQLDatabase_IsTypeOf(PyObject *, PyObject *args)
{
  vtkPythonArgs ap(args, "IsTypeOf");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkPostgreSQLDatabase::IsTypeOf(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkPostgreSQLDatabase_IsA(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsA");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPostgreSQLDatabase *op = static_cast<vtkPostgreSQLDatabase *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->IsA(temp0) :
      op->vtkPostgreSQLDatabase::IsA(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkPostgreSQLDatabase_SafeDownCast(PyObject *, PyObject *args)
{
  vtkPythonArgs ap(args, "SafeDownCast");

  vtkObjectBase *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkObjectBase"))
  {
    vtkPostgreSQLDatabase *tempr = vtkPostgreSQLDatabase::SafeDownCast(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkPostgreSQLDatabase_NewInstance(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "NewInstance");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPostgreSQLDatabase *op = static_cast<vtkPostgreSQLDatabase *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkPostgreSQLDatabase *tempr = (ap.IsBound() ?
      op->NewInstance() :
      op->vtkPostgreSQLDatabase::NewInstance());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
      if (result && PyVTKObject_Check(result))
      {
        PyVTKObject_GetObject(result)->UnRegister(0);
        PyVTKObject_SetFlag(result, VTK_PYTHON_IGNORE_UNREGISTER, 1);
      }
    }
  }

  return result;
}


static PyObject *
PyvtkPostgreSQLDatabase_Open(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "Open");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPostgreSQLDatabase *op = static_cast<vtkPostgreSQLDatabase *>(vp);

  const char *temp0 = 0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0, 1) &&
      (ap.NoArgsLeft() || ap.GetValue(temp0)))
  {
    bool tempr = (ap.IsBound() ?
      op->Open(temp0) :
      op->vtkPostgreSQLDatabase::Open(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkPostgreSQLDatabase_Close(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "Close");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPostgreSQLDatabase *op = static_cast<vtkPostgreSQLDatabase *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->Close();
    }
    else
    {
      op->vtkPostgreSQLDatabase::Close();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkPostgreSQLDatabase_IsOpen(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsOpen");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPostgreSQLDatabase *op = static_cast<vtkPostgreSQLDatabase *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    bool tempr = (ap.IsBound() ?
      op->IsOpen() :
      op->vtkPostgreSQLDatabase::IsOpen());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkPostgreSQLDatabase_GetQueryInstance(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetQueryInstance");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPostgreSQLDatabase *op = static_cast<vtkPostgreSQLDatabase *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkSQLQuery *tempr = (ap.IsBound() ?
      op->GetQueryInstance() :
      op->vtkPostgreSQLDatabase::GetQueryInstance());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
      if (result && PyVTKObject_Check(result))
      {
        PyVTKObject_GetObject(result)->UnRegister(0);
        PyVTKObject_SetFlag(result, VTK_PYTHON_IGNORE_UNREGISTER, 1);
      }
    }
  }

  return result;
}


static PyObject *
PyvtkPostgreSQLDatabase_HasError(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "HasError");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPostgreSQLDatabase *op = static_cast<vtkPostgreSQLDatabase *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    bool tempr = (ap.IsBound() ?
      op->HasError() :
      op->vtkPostgreSQLDatabase::HasError());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkPostgreSQLDatabase_GetLastErrorText(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetLastErrorText");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPostgreSQLDatabase *op = static_cast<vtkPostgreSQLDatabase *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    const char *tempr = (ap.IsBound() ?
      op->GetLastErrorText() :
      op->vtkPostgreSQLDatabase::GetLastErrorText());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkPostgreSQLDatabase_GetDatabaseType(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetDatabaseType");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPostgreSQLDatabase *op = static_cast<vtkPostgreSQLDatabase *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    const char *tempr = (ap.IsBound() ?
      op->GetDatabaseType() :
      op->vtkPostgreSQLDatabase::GetDatabaseType());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkPostgreSQLDatabase_SetHostName(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetHostName");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPostgreSQLDatabase *op = static_cast<vtkPostgreSQLDatabase *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetHostName(temp0);
    }
    else
    {
      op->vtkPostgreSQLDatabase::SetHostName(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkPostgreSQLDatabase_GetHostName(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetHostName");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPostgreSQLDatabase *op = static_cast<vtkPostgreSQLDatabase *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    char *tempr = (ap.IsBound() ?
      op->GetHostName() :
      op->vtkPostgreSQLDatabase::GetHostName());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkPostgreSQLDatabase_SetUser(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetUser");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPostgreSQLDatabase *op = static_cast<vtkPostgreSQLDatabase *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetUser(temp0);
    }
    else
    {
      op->vtkPostgreSQLDatabase::SetUser(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkPostgreSQLDatabase_GetUser(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetUser");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPostgreSQLDatabase *op = static_cast<vtkPostgreSQLDatabase *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    char *tempr = (ap.IsBound() ?
      op->GetUser() :
      op->vtkPostgreSQLDatabase::GetUser());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkPostgreSQLDatabase_SetPassword(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetPassword");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPostgreSQLDatabase *op = static_cast<vtkPostgreSQLDatabase *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetPassword(temp0);
    }
    else
    {
      op->vtkPostgreSQLDatabase::SetPassword(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkPostgreSQLDatabase_SetDatabaseName(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetDatabaseName");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPostgreSQLDatabase *op = static_cast<vtkPostgreSQLDatabase *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetDatabaseName(temp0);
    }
    else
    {
      op->vtkPostgreSQLDatabase::SetDatabaseName(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkPostgreSQLDatabase_GetDatabaseName(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetDatabaseName");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPostgreSQLDatabase *op = static_cast<vtkPostgreSQLDatabase *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    char *tempr = (ap.IsBound() ?
      op->GetDatabaseName() :
      op->vtkPostgreSQLDatabase::GetDatabaseName());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkPostgreSQLDatabase_SetConnectOptions(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetConnectOptions");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPostgreSQLDatabase *op = static_cast<vtkPostgreSQLDatabase *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetConnectOptions(temp0);
    }
    else
    {
      op->vtkPostgreSQLDatabase::SetConnectOptions(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkPostgreSQLDatabase_GetConnectOptions(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetConnectOptions");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPostgreSQLDatabase *op = static_cast<vtkPostgreSQLDatabase *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    char *tempr = (ap.IsBound() ?
      op->GetConnectOptions() :
      op->vtkPostgreSQLDatabase::GetConnectOptions());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkPostgreSQLDatabase_SetServerPort(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetServerPort");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPostgreSQLDatabase *op = static_cast<vtkPostgreSQLDatabase *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetServerPort(temp0);
    }
    else
    {
      op->vtkPostgreSQLDatabase::SetServerPort(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkPostgreSQLDatabase_GetServerPortMinValue(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetServerPortMinValue");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPostgreSQLDatabase *op = static_cast<vtkPostgreSQLDatabase *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetServerPortMinValue() :
      op->vtkPostgreSQLDatabase::GetServerPortMinValue());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkPostgreSQLDatabase_GetServerPortMaxValue(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetServerPortMaxValue");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPostgreSQLDatabase *op = static_cast<vtkPostgreSQLDatabase *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetServerPortMaxValue() :
      op->vtkPostgreSQLDatabase::GetServerPortMaxValue());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkPostgreSQLDatabase_GetServerPort(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetServerPort");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPostgreSQLDatabase *op = static_cast<vtkPostgreSQLDatabase *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetServerPort() :
      op->vtkPostgreSQLDatabase::GetServerPort());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkPostgreSQLDatabase_GetURL(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetURL");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPostgreSQLDatabase *op = static_cast<vtkPostgreSQLDatabase *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkStdString tempr = (ap.IsBound() ?
      op->GetURL() :
      op->vtkPostgreSQLDatabase::GetURL());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkPostgreSQLDatabase_GetTables(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetTables");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPostgreSQLDatabase *op = static_cast<vtkPostgreSQLDatabase *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkStringArray *tempr = (ap.IsBound() ?
      op->GetTables() :
      op->vtkPostgreSQLDatabase::GetTables());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkPostgreSQLDatabase_GetRecord(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetRecord");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPostgreSQLDatabase *op = static_cast<vtkPostgreSQLDatabase *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    vtkStringArray *tempr = (ap.IsBound() ?
      op->GetRecord(temp0) :
      op->vtkPostgreSQLDatabase::GetRecord(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkPostgreSQLDatabase_IsSupported(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsSupported");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPostgreSQLDatabase *op = static_cast<vtkPostgreSQLDatabase *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    bool tempr = (ap.IsBound() ?
      op->IsSupported(temp0) :
      op->vtkPostgreSQLDatabase::IsSupported(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkPostgreSQLDatabase_GetDatabases(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetDatabases");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPostgreSQLDatabase *op = static_cast<vtkPostgreSQLDatabase *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkStringArray *tempr = (ap.IsBound() ?
      op->GetDatabases() :
      op->vtkPostgreSQLDatabase::GetDatabases());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkPostgreSQLDatabase_CreateDatabase(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "CreateDatabase");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPostgreSQLDatabase *op = static_cast<vtkPostgreSQLDatabase *>(vp);

  const char *temp0 = nullptr;
  bool temp1 = false;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1, 2) &&
      ap.GetValue(temp0) &&
      (ap.NoArgsLeft() || ap.GetValue(temp1)))
  {
    bool tempr = (ap.IsBound() ?
      op->CreateDatabase(temp0, temp1) :
      op->vtkPostgreSQLDatabase::CreateDatabase(temp0, temp1));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkPostgreSQLDatabase_DropDatabase(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "DropDatabase");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPostgreSQLDatabase *op = static_cast<vtkPostgreSQLDatabase *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    bool tempr = (ap.IsBound() ?
      op->DropDatabase(temp0) :
      op->vtkPostgreSQLDatabase::DropDatabase(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkPostgreSQLDatabase_GetColumnSpecification(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetColumnSpecification");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPostgreSQLDatabase *op = static_cast<vtkPostgreSQLDatabase *>(vp);

  vtkSQLDatabaseSchema *temp0 = nullptr;
  int temp1;
  int temp2;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(3) &&
      ap.GetVTKObject(temp0, "vtkSQLDatabaseSchema") &&
      ap.GetValue(temp1) &&
      ap.GetValue(temp2))
  {
    vtkStdString tempr = (ap.IsBound() ?
      op->GetColumnSpecification(temp0, temp1, temp2) :
      op->vtkPostgreSQLDatabase::GetColumnSpecification(temp0, temp1, temp2));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkPostgreSQLDatabase_ParseURL(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ParseURL");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPostgreSQLDatabase *op = static_cast<vtkPostgreSQLDatabase *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    bool tempr = (ap.IsBound() ?
      op->ParseURL(temp0) :
      op->vtkPostgreSQLDatabase::ParseURL(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}

static PyMethodDef PyvtkPostgreSQLDatabase_Methods[] = {
  {"IsTypeOf", PyvtkPostgreSQLDatabase_IsTypeOf, METH_VARARGS,
   "V.IsTypeOf(string) -> int\nC++: static vtkTypeBool IsTypeOf(const char *type)\n\nReturn 1 if this class type is the same type of (or a subclass\nof) the named class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"IsA", PyvtkPostgreSQLDatabase_IsA, METH_VARARGS,
   "V.IsA(string) -> int\nC++: vtkTypeBool IsA(const char *type) override;\n\nReturn 1 if this class is the same type of (or a subclass of) the\nnamed class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SafeDownCast", PyvtkPostgreSQLDatabase_SafeDownCast, METH_VARARGS,
   "V.SafeDownCast(vtkObjectBase) -> vtkPostgreSQLDatabase\nC++: static vtkPostgreSQLDatabase *SafeDownCast(vtkObjectBase *o)\n\n"},
  {"NewInstance", PyvtkPostgreSQLDatabase_NewInstance, METH_VARARGS,
   "V.NewInstance() -> vtkPostgreSQLDatabase\nC++: vtkPostgreSQLDatabase *NewInstance()\n\n"},
  {"Open", PyvtkPostgreSQLDatabase_Open, METH_VARARGS,
   "V.Open(string) -> bool\nC++: bool Open(const char *password=0) override;\n\nOpen a new connection to the database.  You need to set the\nfilename before calling this function.  Returns true if the\ndatabase was opened successfully; false otherwise.\n"},
  {"Close", PyvtkPostgreSQLDatabase_Close, METH_VARARGS,
   "V.Close()\nC++: void Close() override;\n\nClose the connection to the database.\n"},
  {"IsOpen", PyvtkPostgreSQLDatabase_IsOpen, METH_VARARGS,
   "V.IsOpen() -> bool\nC++: bool IsOpen() override;\n\nReturn whether the database has an open connection\n"},
  {"GetQueryInstance", PyvtkPostgreSQLDatabase_GetQueryInstance, METH_VARARGS,
   "V.GetQueryInstance() -> vtkSQLQuery\nC++: vtkSQLQuery *GetQueryInstance() override;\n\nReturn an empty query on this database.\n"},
  {"HasError", PyvtkPostgreSQLDatabase_HasError, METH_VARARGS,
   "V.HasError() -> bool\nC++: virtual bool HasError() override;\n\nDid the last operation generate an error\n"},
  {"GetLastErrorText", PyvtkPostgreSQLDatabase_GetLastErrorText, METH_VARARGS,
   "V.GetLastErrorText() -> string\nC++: const char *GetLastErrorText() override;\n\nGet the last error text from the database\n"},
  {"GetDatabaseType", PyvtkPostgreSQLDatabase_GetDatabaseType, METH_VARARGS,
   "V.GetDatabaseType() -> string\nC++: const char *GetDatabaseType() override;\n\nString representing database type (e.g. \"psql\").\n"},
  {"SetHostName", PyvtkPostgreSQLDatabase_SetHostName, METH_VARARGS,
   "V.SetHostName(string)\nC++: virtual void SetHostName(const char *)\n\nThe database server host name.\n"},
  {"GetHostName", PyvtkPostgreSQLDatabase_GetHostName, METH_VARARGS,
   "V.GetHostName() -> string\nC++: virtual char *GetHostName()\n\nThe database server host name.\n"},
  {"SetUser", PyvtkPostgreSQLDatabase_SetUser, METH_VARARGS,
   "V.SetUser(string)\nC++: virtual void SetUser(const char *)\n\nThe user name for connecting to the database server.\n"},
  {"GetUser", PyvtkPostgreSQLDatabase_GetUser, METH_VARARGS,
   "V.GetUser() -> string\nC++: virtual char *GetUser()\n\nThe user name for connecting to the database server.\n"},
  {"SetPassword", PyvtkPostgreSQLDatabase_SetPassword, METH_VARARGS,
   "V.SetPassword(string)\nC++: virtual void SetPassword(const char *)\n\nThe user's password for connecting to the database server.\n"},
  {"SetDatabaseName", PyvtkPostgreSQLDatabase_SetDatabaseName, METH_VARARGS,
   "V.SetDatabaseName(string)\nC++: virtual void SetDatabaseName(const char *)\n\nThe name of the database to connect to.\n"},
  {"GetDatabaseName", PyvtkPostgreSQLDatabase_GetDatabaseName, METH_VARARGS,
   "V.GetDatabaseName() -> string\nC++: virtual char *GetDatabaseName()\n\nThe name of the database to connect to.\n"},
  {"SetConnectOptions", PyvtkPostgreSQLDatabase_SetConnectOptions, METH_VARARGS,
   "V.SetConnectOptions(string)\nC++: virtual void SetConnectOptions(const char *)\n\nAdditional options for the database.\n"},
  {"GetConnectOptions", PyvtkPostgreSQLDatabase_GetConnectOptions, METH_VARARGS,
   "V.GetConnectOptions() -> string\nC++: virtual char *GetConnectOptions()\n\nAdditional options for the database.\n"},
  {"SetServerPort", PyvtkPostgreSQLDatabase_SetServerPort, METH_VARARGS,
   "V.SetServerPort(int)\nC++: virtual void SetServerPort(int)\n\nThe port used for connecting to the database.\n"},
  {"GetServerPortMinValue", PyvtkPostgreSQLDatabase_GetServerPortMinValue, METH_VARARGS,
   "V.GetServerPortMinValue() -> int\nC++: virtual int GetServerPortMinValue()\n\nThe port used for connecting to the database.\n"},
  {"GetServerPortMaxValue", PyvtkPostgreSQLDatabase_GetServerPortMaxValue, METH_VARARGS,
   "V.GetServerPortMaxValue() -> int\nC++: virtual int GetServerPortMaxValue()\n\nThe port used for connecting to the database.\n"},
  {"GetServerPort", PyvtkPostgreSQLDatabase_GetServerPort, METH_VARARGS,
   "V.GetServerPort() -> int\nC++: virtual int GetServerPort()\n\nThe port used for connecting to the database.\n"},
  {"GetURL", PyvtkPostgreSQLDatabase_GetURL, METH_VARARGS,
   "V.GetURL() -> string\nC++: vtkStdString GetURL() override;\n\nGet a URL referencing the current database connection. This is\nnot well-defined if the HostName and DatabaseName have not been\nset. The URL will be of the form\n'psql://'[username[':'password]'@']hostname[':'port]'/'database.\n"},
  {"GetTables", PyvtkPostgreSQLDatabase_GetTables, METH_VARARGS,
   "V.GetTables() -> vtkStringArray\nC++: vtkStringArray *GetTables() override;\n\nGet the list of tables from the database\n"},
  {"GetRecord", PyvtkPostgreSQLDatabase_GetRecord, METH_VARARGS,
   "V.GetRecord(string) -> vtkStringArray\nC++: vtkStringArray *GetRecord(const char *table) override;\n\nGet the list of fields for a particular table\n"},
  {"IsSupported", PyvtkPostgreSQLDatabase_IsSupported, METH_VARARGS,
   "V.IsSupported(int) -> bool\nC++: bool IsSupported(int feature) override;\n\nReturn whether a feature is supported by the database.\n"},
  {"GetDatabases", PyvtkPostgreSQLDatabase_GetDatabases, METH_VARARGS,
   "V.GetDatabases() -> vtkStringArray\nC++: vtkStringArray *GetDatabases()\n\nReturn a list of databases on the server.\n"},
  {"CreateDatabase", PyvtkPostgreSQLDatabase_CreateDatabase, METH_VARARGS,
   "V.CreateDatabase(string, bool) -> bool\nC++: bool CreateDatabase(const char *dbName,\n    bool dropExisting=false)\n\nCreate a new database, optionally dropping any existing database\nof the same name. Returns true when the database is properly\ncreated and false on failure.\n"},
  {"DropDatabase", PyvtkPostgreSQLDatabase_DropDatabase, METH_VARARGS,
   "V.DropDatabase(string) -> bool\nC++: bool DropDatabase(const char *dbName)\n\nDrop a database if it exists. Returns true on success and false\non failure.\n"},
  {"GetColumnSpecification", PyvtkPostgreSQLDatabase_GetColumnSpecification, METH_VARARGS,
   "V.GetColumnSpecification(vtkSQLDatabaseSchema, int, int) -> string\nC++: vtkStdString GetColumnSpecification(\n    vtkSQLDatabaseSchema *schema, int tblHandle, int colHandle)\n    override;\n\nReturn the SQL string with the syntax to create a column inside a \"CREATE\nTABLE\" SQL statement. NB: this method implements the\nPostgreSQL-specific syntax: <column name> <column type> <column\nattributes>\n"},
  {"ParseURL", PyvtkPostgreSQLDatabase_ParseURL, METH_VARARGS,
   "V.ParseURL(string) -> bool\nC++: bool ParseURL(const char *url) override;\n\nOverridden to determine connection parameters given the URL. This\nis called by CreateFromURL() to initialize the instance. Look at\nCreateFromURL() for details about the URL format.\n"},
  {nullptr, nullptr, 0, nullptr}
};

static PyTypeObject PyvtkPostgreSQLDatabase_Type = {
  PyVarObject_HEAD_INIT(&PyType_Type, 0)
  "vtkIOPostgreSQLPython.vtkPostgreSQLDatabase", // tp_name
  sizeof(PyVTKObject), // tp_basicsize
  0, // tp_itemsize
  PyVTKObject_Delete, // tp_dealloc
  0, // tp_vectorcall_offset
  nullptr, // tp_getattr
  nullptr, // tp_setattr
  nullptr, // tp_compare
  PyVTKObject_Repr, // tp_repr
  nullptr, // tp_as_number
  nullptr, // tp_as_sequence
  nullptr, // tp_as_mapping
  nullptr, // tp_hash
  nullptr, // tp_call
  PyVTKObject_String, // tp_str
  PyObject_GenericGetAttr, // tp_getattro
  PyObject_GenericSetAttr, // tp_setattro
  &PyVTKObject_AsBuffer, // tp_as_buffer
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_BASETYPE, // tp_flags
  PyvtkPostgreSQLDatabase_Doc, // tp_doc
  PyVTKObject_Traverse, // tp_traverse
  nullptr, // tp_clear
  nullptr, // tp_richcompare
  offsetof(PyVTKObject, vtk_weakreflist), // tp_weaklistoffset
  nullptr, // tp_iter
  nullptr, // tp_iternext
  nullptr, // tp_methods
  nullptr, // tp_members
  PyVTKObject_GetSet, // tp_getset
  nullptr, // tp_base
  nullptr, // tp_dict
  nullptr, // tp_descr_get
  nullptr, // tp_descr_set
  offsetof(PyVTKObject, vtk_dict), // tp_dictoffset
  nullptr, // tp_init
  nullptr, // tp_alloc
  PyVTKObject_New, // tp_new
  PyObject_GC_Del, // tp_free
  nullptr, // tp_is_gc
  nullptr, // tp_bases
  nullptr, // tp_mro
  nullptr, // tp_cache
  nullptr, // tp_subclasses
  nullptr, // tp_weaklist
  VTK_WRAP_PYTHON_SUPPRESS_UNINITIALIZED
};

static vtkObjectBase *PyvtkPostgreSQLDatabase_StaticNew()
{
  return vtkPostgreSQLDatabase::New();
}

PyObject *PyvtkPostgreSQLDatabase_ClassNew()
{
  PyVTKClass_Add(
    &PyvtkPostgreSQLDatabase_Type, PyvtkPostgreSQLDatabase_Methods,
    "vtkPostgreSQLDatabase",
 &PyvtkPostgreSQLDatabase_StaticNew);

  PyTypeObject *pytype = &PyvtkPostgreSQLDatabase_Type;

  if ((pytype->tp_flags & Py_TPFLAGS_READY) != 0)
  {
    return (PyObject *)pytype;
  }

#if !defined(VTK_PY3K) && PY_VERSION_HEX >= 0x02060000
  pytype->tp_flags |= Py_TPFLAGS_HAVE_NEWBUFFER;
#endif

  pytype->tp_base = (PyTypeObject *)PyvtkSQLDatabase_ClassNew();

  PyType_Ready(pytype);
  return (PyObject *)pytype;
}

void PyVTKAddFile_vtkPostgreSQLDatabase(
  PyObject *dict)
{
  PyObject *o;
  o = PyvtkPostgreSQLDatabase_ClassNew();

  if (o && PyDict_SetItemString(dict, "vtkPostgreSQLDatabase", o) != 0)
  {
    Py_DECREF(o);
  }

}

